@@ -13,6 +13,7 @@
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
 ### END LICENSE
+import base64
 import codecs
 import datetime
 import functools
@@ -30,6 +31,7 @@ import sys
 import threading
 import time
 import urllib.parse
+from itertools import cycle
 
 import bs4
 import requests
@@ -602,7 +604,7 @@ class Util:
         return f
 
     @staticmethod
-    def request(url, data=None, stream=False, method=None, timeout=5, headers=None, verify=True):
+    def request(url, data=None, stream=False, method=None, timeout=5, headers=None):
         if url.startswith("//"):
             url = "http:" + url
         headers = headers or {}
@@ -617,7 +619,6 @@ class Util:
                 stream=stream,
                 allow_redirects=True,
                 timeout=timeout,
-                verify=verify,
             )
             r.raise_for_status()
             return r
@@ -650,6 +651,11 @@ class Util:
     def xml_soup(url, data=None, **request_kwargs):
         return bs4.BeautifulSoup(Util.fetch(url, data, **request_kwargs), "xml")
 
+    @staticmethod
+    def unxor(text, key):
+        ciphertext = base64.decodestring(text)
+        return "".join(chr(x ^ ord(y)) for (x, y) in zip(ciphertext, cycle(key)))
+
     @staticmethod
     def folderpath(folder):
         p = os.path.normpath(folder)
